src.Core package — AsyncPywhatKit 1.1.0.0 documentation

# src.Core package

## Submodules

## src.Core.core module

async src.Core.core.check_connection() → None

  Check the Internet connection of the Host Machine

async src.Core.core.check_number(number: str) → bool

  Checks if the Number is Valid or not

async src.Core.core.close_tab(wait_time: int = 2) → None

  Closes the Currently Opened Browser Tab

async src.Core.core.find_document()

async src.Core.core.find_link()

async src.Core.core.find_photo_or_video()

src.Core.core.find_recent_chat()

async src.Core.core.findtextbox() → None

  click on text box

async src.Core.core.send_message(message: str, receiver: str, wait_time: int) → None

  Parses and Sends the Message

## src.Core.exceptions module

exception src.Core.exceptions.CallTimeException

  Bases: `Exception`

  Wait time is too short for WhatsApp Web to Open

exception src.Core.exceptions.CountryCodeException

  Bases: `Exception`

  Country Code is not present in the Phone Number

exception src.Core.exceptions.InternetException

  Bases: `Exception`

  Host machine is not connected to the Internet or the connection Speed is Slow

exception src.Core.exceptions.InvalidPhoneNumber

  Bases: `Exception`

  Phone number given is invalid

exception src.Core.exceptions.UnableToAccessApi

  Bases: `Exception`

  unable to access pywhatkit api

exception src.Core.exceptions.UnsupportedEmailProvider

  Bases: `Exception`

  Email provider used to send the Email is not supported

## src.Core.log module

async src.Core.log.format_message(message: str) → str

  Formats the Message to remove redundant Spaces and Newline chars

async src.Core.log.log_image(_time: struct_time, path: str, receiver: str, caption: str) → None

  Logs the Image Information after it is Sent

async src.Core.log.log_message(_time: struct_time, receiver: str, message: str) → None

  Logs the Message Information after it is Sent

## Module contents